@@ -131,7 +131,8 @@ class ExtARQ(base.CyborgObject, object_base.VersionedObjectDictCompat,
         ea = ExtARQ.get(context, self.arq.uuid, lock=True)
         if not ea:
             raise exception.ResourceNotFound(
-                "Can not find ExtARQ(%s)" % self.arq.uuid)
+                resources='ExtARQ',
+                msg="Can not find ExtARQ(%s)" % self.arq.uuid)
         current = ea.arq.state
         if state != current:
             msg = ("Failed to change ARQ state from %s to %s, the current "
@@ -152,14 +153,25 @@ class ExtARQ(base.CyborgObject, object_base.VersionedObjectDictCompat,
 
         This is not idempotent, i.e., if the first call to delete an
         ARQ has succeeded, second and later calls to delete the same ARQ
-        will get errored out.
+        will get errored out, but it will raise the exception only after
+        all input arq being operated.
         """
+        unexisted = []
         for uuid in arq_uuid_list:
-            obj_extarq = objects.ExtARQ.get(context, uuid)
-            # TODO() Defer deletion to conductor
-            if obj_extarq.arq.state != constants.ARQ_INITIAL:
-                obj_extarq.unbind(context)
-            obj_extarq.destroy(context)
+            try:
+                obj_extarq = objects.ExtARQ.get(context, uuid)
+                # TODO() Defer deletion to conductor
+                if obj_extarq.arq.state != constants.ARQ_INITIAL:
+                    obj_extarq.unbind(context)
+                obj_extarq.destroy(context)
+            except exception.ResourceNotFound:
+                unexisted.append(uuid)
+                continue
+        if unexisted:
+            LOG.warning('There are unexisted arqs: %s', unexisted)
+            raise exception.ResourceNotFound(
+                resource='ARQ',
+                msg='with uuids %s' % unexisted)
 
     @classmethod
     def delete_by_instance(cls, context, instance_uuid):
@@ -249,8 +261,8 @@ class ExtARQ(base.CyborgObject, object_base.VersionedObjectDictCompat,
                 db_extarq['attach_handle_info'] = db_ah['attach_info']
             else:
                 raise exception.ResourceNotFound(
-                    resource='attach handle',
-                    msg='')
+                    resource='Attach Handle',
+                    msg='with uuid=%s' % db_extarq['attach_handle_id'])
 
         if db_extarq['deployable_id']:
             dep = objects.Deployable.get_by_id(db_extarq['deployable_id'])
